@@ -126,7 +126,8 @@ class Key:
 
 		universe = ['a', 'as', 'b', 'c', 'cs', 'd', 'ds', 'e', 'f', 'fs', 'g', 'gs'] * 2
 		self.universal_chords = chords
-		self.universal_notes = universe
+		self.universal_notes = notes.all
+		self.list_universal_notes = universe
 		W = 2
 		H = 1
 		if 'major' in name.lower() and name[0].lower() in universe:
@@ -268,6 +269,18 @@ class Key:
 		pents = self.notes_in_pentatonic_minor()
 		return list(pents.keys())
 
+	def list_notes_in_harmonic_minor(self):
+		if self.seniority == 'minor':
+			diatonics = self.list_notes_in_mode('ionian')
+			target = diatonics[-1]
+			new_target = self.list_universal_notes[self.list_universal_notes.index(target) + 1]
+			diatonics.pop(-1)
+			diatonics.append(new_target)
+			return diatonics
+		else:
+			name = self.name.split('_')[0] + '_minor'
+			alt_self = Key(name)
+			return alt_self.list_notes_in_harmonic_minor()
 
 	# RETURNS DICT
 	def notes_in_mode(self, modename):
@@ -288,22 +301,21 @@ class Key:
 
 	def notes_in_pentatonic_minor(self):
 		new_dict = {}
-		notes = Notes()
 		if self.seniority == 'minor':
 			scale = self.list_notes_in_mode('ionian')
 			try:
-				flatted_three = self.universal_notes[self.universal_notes.index(scale[2])]
+				flatted_three = self.list_universal_notes[self.list_universal_notes.index(scale[2])]
 			except:
-				flatted_three = self.universal_notes[self.universal_notes.index('gs')]
+				flatted_three = self.list_universal_notes[self.list_universal_notes.index('gs')]
 			try:
-				flatted_seventh = self.universal_notes[self.universal_notes.index(scale[6])]
+				flatted_seventh = self.list_universal_notes[self.list_universal_notes.index(scale[6])]
 			except:
-				flatted_seventh = self.universal_notes[self.universal_notes.index('gs')]
+				flatted_seventh = self.list_universal_notes[self.list_universal_notes.index('gs')]
 
 			pentatonics = [scale[0], flatted_three, scale[3], scale[4], flatted_seventh]
 
 			for i in pentatonics:
-				new_dict[i] = notes.all[i]
+				new_dict[i] = self.universal_notes[i]
 
 			return new_dict
 
@@ -315,13 +327,12 @@ class Key:
 
 	def notes_in_pentatonic_major(self):
 		new_dict = {}
-		notes = Notes()
 		if self.seniority == 'major':
 			pentatonics = self.list_notes_in_mode('ionian')
 			pentatonics.pop(6)
 			pentatonics.pop(3)
 			for i in pentatonics:
-				new_dict[i] = notes.all[i]
+				new_dict[i] = self.universal_notes[i]
 			return new_dict
 
 		elif self.seniority == 'minor':
@@ -331,9 +342,6 @@ class Key:
 			return k.notes_in_pentatonic_major()
 
 
-
-
-
 def list_modes():
 	return [
 		'ionian',
